//
// GameX
// Ship Demo - Photon Class Header
//
// Copyright (C) 2002 Rama C. Hoetzlein
// 
// This software is released under the GameX GNU GPL 
// Open Source License. See the GameX documentation included
// with this source code for terms of modification, 
// distribution and re-release. 
// 


#ifndef PHOTONS_DEFINED
	#define PHOTONS_DEFINED

	#include "gamex.h"
	
	// Photons are implemented as a simple 2-dimensional particle system.

	#define MAX_AGE 48					// Photon constant, maximum age of g_photons
	#define MAX_PHOTONS 1024			// Photon constant, maximum g_photons active at once

	struct Photon {						//*** Photon structure
		Vec2f		pos;				// Position of photon (in game screen pixel coordinates)
		Vec2f		vel;				// Velocity of photon
		int			age;				// Age of photon, 0 meaning new
		int			img;				// Image number of photon (only image # 0 is used for now)
	};

	class Photons {						//*** Photon class
	public:
		void Initialize (void);			// Initialize system of g_photons (i.e. load the necessary image(s))
		void Update (void);				// Move all g_photons
		void Draw (void);				// Draw all g_photons
										// Add a photon to the system:
		int AddPhoton (const Vec2f & pos, const Vec2f & vel);
	private:
		// use a statically sized array to hold the photons, as a simplification and an optimization
		int		_numPhotons;				// Current number of g_photons used out of MAX_PHOTONS
		Photon	_photonList[MAX_PHOTONS];	// Array of g_photons (ie. 'the particle system')

		ImageX	_photonImg[1];				// Photon images (only 1 image currently used)
	};

	extern Photons g_photons;				// Global photons object

#endif