//
// GameX
// Ship Demo - Ship Class Header
// 
// Copyright (C) 2002 Rama C. Hoetzlein
// 
// This software is released under the GameX GNU GPL 
// Open Source License. See the GameX documentation included
// with this source code for terms of modification, 
// distribution and re-release. 
// 

#ifndef SHIP_DEFINED
	#define SHIP_DEFINED

	#include "gamex.h"

	// The Ships are implemented as simple Finite-State-Machines
											
	#define SHIP_IMG_RIGHT			0		// Ship Frame Sprite Numbers:
	#define SHIP_IMG_FLAT			9
	#define SHIP_IMG_LEFT			17

	class Ship								//*** Ship class
	{							
	public:
		void Initialize (int shipNum);		// Initialize ship of number 'shipNum'
		void Update (void);					// Get user input and move the ship
		void Draw (void);					// Draw the ship
		
		void CollideCheck (Ship* ship2);	// Collision Detection with another ship

		const Vec2f & GetPos (void) const {return _pos;}	// Get position and velocity of ship
		const Vec2f & GetVel (void) const {return _vel;}
		const float GetMass (void) const {return _weight;}
	private:
		int			_shipNum;				// Current ship number
		
		float		_ang, _dang;			// Angle of ship (and change in angle)
		Vec2f		_pos;					// Position of ship
		Vec2f		_vel;					// Velocity of ship
		int			_refire;				// Refire counter for ship
		float		_weight;				// How heavy the ship is

		int			_currImg;				// Current ship image
		Vec2f		_target;				// Offset of ship's target
		
		ImageX		_sprites;				// Ship images of this ship
		ImageX		_targetImg;				// Ship's Target image

		SoundX		_photonSnd;				// Sound of photon firing
	};

#endif